"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var fs_1 = tslib_1.__importDefault(require("fs"));
var path_1 = tslib_1.__importDefault(require("path"));
var constants_1 = require("./constants");
exports.tryPkg = function (pkg) {
    try {
        return require.resolve(pkg);
    }
    catch (_a) { }
};
exports.isPkgAvailable = function (pkg) { return !!exports.tryPkg(pkg); };
exports.isTsAvailable = exports.isPkgAvailable('typescript');
exports.isAngularAvailable = exports.isPkgAvailable('@angular/core');
exports.isMdxAvailable = exports.isPkgAvailable('@mdx/mdx') || exports.isPkgAvailable('@mdx/react');
exports.isReactAvailable = exports.isPkgAvailable('react');
exports.isSvelteAvailable = exports.isPkgAvailable('svelte');
exports.isVueAvailable = exports.isPkgAvailable('vue');
exports.tryFile = function (filePath, includeDir) {
    if (typeof filePath === 'string') {
        return fs_1.default.existsSync(filePath) &&
            (includeDir || fs_1.default.statSync(filePath).isFile())
            ? filePath
            : '';
    }
    for (var _i = 0, _a = filePath || []; _i < _a.length; _i++) {
        var file = _a[_i];
        if (exports.tryFile(file, includeDir)) {
            return file;
        }
    }
    return '';
};
exports.tryExtensions = function (filepath, extensions) {
    if (extensions === void 0) { extensions = constants_1.EXTENSIONS; }
    var ext = extensions.concat('').find(function (ext) { return exports.tryFile(filepath + ext); });
    return ext == null ? '' : filepath + ext;
};
exports.identify = function (_) { return !!_; };
exports.findUp = function (searchEntry, searchFile) {
    if (searchFile === void 0) { searchFile = 'package.json'; }
    console.assert(path_1.default.isAbsolute(searchEntry));
    if (!exports.tryFile(searchEntry, true) ||
        (searchEntry !== constants_1.CWD && !searchEntry.startsWith(constants_1.CWD + path_1.default.sep))) {
        return '';
    }
    searchEntry = path_1.default.resolve(fs_1.default.statSync(searchEntry).isDirectory()
        ? searchEntry
        : path_1.default.resolve(searchEntry, '..'));
    do {
        var searched = exports.tryFile(path_1.default.resolve(searchEntry, searchFile));
        if (searched) {
            return searched;
        }
        searchEntry = path_1.default.resolve(searchEntry, '..');
    } while (searchEntry === constants_1.CWD || searchEntry.startsWith(constants_1.CWD + path_1.default.sep));
    return '';
};
//# sourceMappingURL=helpers.js.map